"""
    toolkit_library
    ~~~~~~~~~~~~~~~
    General purpose toolkit library
    In order to use this library, your have to do either of the following:

    1). Install the library via pip. (recommended)
        pip install toolkit_library

    2). Install the library.
        python setup.py install

    3). Add this library to environment variable PYTHONPATH
        export PYTHONPATH=/path/to/toolkit/library
        You can check the variable: echo $PYTHONPATH

    How to use the library:
        from toolkit_library.mail_server import MailServer
        # do something with MailServer

    For more working examples, please refer to tests.py
"""
__version__ = '0.3.1'
__author__ = 'Tyler Long'
